@@ -32,7 +32,6 @@ import (
 	"mynewt.apache.org/newtmgr/nmxact/sesn"
 	"sync"
 	"sync/atomic"
-	"time"
 )
 
 //////////////////////////////////////////////////////////////////////////////
@@ -148,6 +147,11 @@ func findChunkLen(s sesn.Sesn, hash []byte, upgrade bool, data []byte,
 		// Encoded length is larger than MTU, we need to make chunk shorter
 		overflow := len(enc) - s.MtuOut()
 		chunklen -= overflow
+		if chunklen <= 0 {
+			return 0, fmt.Errorf("Cannot create image upload request; "+
+				"MTU too low to fit any image data; max-payload-size=%d chunklen %d",
+				s.MtuOut(), chunklen)
+		}
 	}
 
 	return chunklen, nil
@@ -495,7 +499,7 @@ func (c *ImageUpgradeCmd) runUpload(s sesn.Sesn) (*ImageUploadResult, error) {
 
 	for {
 		var opt = sesn.TxOptions{
-			Timeout: 3 * time.Second,
+			Timeout: c.CmdBase.txOptions.Timeout,
 			Tries:   1,
 		}
 		cmd := NewImageUploadCmd()
